# Tauola README
The TAUOLA external event generator can be used to decay tau particles. 
The syntax for decay.dec files is
```
Decay tau-
<BF>   TAUOLA   <modeInt>;
Enddecay
```
where `<BF>` is the relative branching fraction (0 to 1) and `modeInt` is the 
integer value specifying what TAUOLA decay is to be generated. 
Note that the daughter particle types of the mode are not specified within 
the "Decay" command - the mode integer will generate the correct daughters for you.
Alised tau particles can use the TAUOLA model, but the generated daughters cannot
be aliased particles; there is no simple way to ensure that the order of any 
daughter particle definitions will match the order of the particles generated by 
TAUOLA, especially for the modes with many pions in the final state.

Allowed TAUOLA decay mode integers are (from the TAUOLA documentation):

0   All TAUOLA modes (1 to 22 below)
1   tau- -> e- anti-nu_e nu_tau
2   tau- -> mu- anti-nu_mu nu_tau
3   tau- -> pi- nu_tau
4   tau- -> rho- nu_tau
5   tau- -> a_1- nu_tau
6   tau- -> K- nu_tau
7   tau- -> K*- nu_tau
8   tau- -> 2pi- pi+ pi0 nu_tau
9   tau- -> 3pi0 pi- nu_tau
10  tau- -> 2pi- pi+ 2pi0 nu_tau
11  tau- -> 3pi- 2pi+ nu_tau
12  tau- -> 3pi- 2pi+ pi0 nu_tau
13  tau- -> 2pi- pi+ 3pi0 nu_tau
14  tau- -> K- K+ pi- nu_tau
15  tau- -> K0 anti-K0 pi- nu_tau
16  tau- -> K- anti-K0 pi0 nu_tau
17  tau- -> 2pi0 K- nu_tau
18  tau- -> pi- pi+ K- nu_tau
19  tau- -> pi- pi0 K0 nu_tau
20  tau- -> eta pi- pi0 nu_tau
21  tau- -> pi- pi0 gamma nu_tau
22  tau- -> K- K0 nu_tau

For example, to generate tau- -> 3pi0 pi- nu_tau (40%) and 
tau- -> mu- anti-nu_mu nu_tau (60%), use
```
Decay Mytau-
0.4  TAUOLA 9;
0.6  TAUOLA 2;
Enddecay
CDecay Mytau+
```
To ensure decay mode consistency, any tau particle decay definition (normal or alised)
using TAUOLA should use it for all sub-modes, i.e do not mix TAUOLA and other
decay models, such as phase space (PHSP), within the same "Decay" definition.

An example which is NOT allowed is:
```
Decay Mytau+
0.4  TAUOLA 9;
0.5  TAUOLA 2;
0.1  e+ nu_e anti-nu_tau PHSP;  # Decay model is not TAUOLA.
Enddecay
```
If this is detected, the program will stop and ask you to correct the decay definition(s). 
The reason for this limitation is due to the fact that TAUOLA decays any tau particles 
by considering the kinematics of its parent particle and the rest of the daughters, one of 
which is the tau particle itself and other tau particles (charged or neutrino) that 
are there in order to conserve tau lepton number. We let TAUOLA decay _all_ tau particle 
types within the decay tree. EvtGen is then prevented from decaying the other tau 
particle(s), since TAUOLA has already done that. If other physics models are used for the 
other tau particle(s), then the correlated decay kinematics generated by TAUOLA will be 
lost, leading to unphysical results.

If a particle decay contains at least two tau particles, and one of these uses TAUOLA
decay modes, then all other tau particles should use the same TAUOLA decay definitions to
ensure consistency:
```
Alias MyB0 B0
Alias Myanti-B0 anti-B0
ChargeConj Myanti-B0 MyB0

Alias Mytau+ tau+
Alias Mytau- tau-
ChargeConj Mytau- Mytau+

Decay MyB0
1.0  Mytau+  Mytau-  PHSP;
Enddecay
CDecay Myanti-B0

Decay Mytau+
0.4 TAUOLA 9;
0.6 TAUOLA 2;
Enddecay
CDecay Mytau-
```
You should not define two or more (via aliases) tau decays with different TAUOLA 
sub-mode branching fractions. Also tau- and tau+ particles must have the same decay 
modes/branching fractions. These limitions are due to the fact that the core code 
of TAUOLA is FORTRAN, and changing the TAUOLA mode parameters for one tau particle will 
affect it for all other tau particles as well. So, EvtGen will only initialise 
TAUOLA modes when it counters the first tau-type particle in the "evt.pdl" file that 
has a TAUOLA decay mode defined for it. So, for example, if TAUOLA decays are 
defined for "tau-", which corresponds to the first tau particle in the evt.pdl file, then 
other TAUOLA decay definitions will be ignored, and the modes defined for tau- will also 
be used for tau+ etc.. It is important to make sure the decay file uses the TAUOLA 
mode definitions correctly to ensure consistency in decay tree results/information:

1) Decide what tau modes you want from TAUOLA.
2) Define the allowed decay modes for the tau- and tau+ particle, using only TAUOLA modes.
   It is possible to keep the decay.dec generic (non-TAUOLA) decay modes for tau- and tau+, and 
   create aliased tau ("signal") particles such as Mytau- and Mytau+ to only use TAUOLA modes:
```
Alias Mytau- tau-
Alias Mytau+ tau+
ChargeConj Mytau+ Mytau-

Decay Mytau-
0.4  TAUOLA 9;
0.6  TAUOLA 2;
Enddecay
CDecay Mytau+
```
3) Make sure the TAUOLA modes for tau+ match those for tau- (easily done by using "CDecay").
4) Do not create other (alised) tau particles using TAUOLA modes. These settings will be ignored.


The PHOTOS generator can be used with the TAUOLA code, although the only way at present to
have this enabled is to set the "yesPhotos" global option in the decay.dec file. This means
that PHOTOS will be turned on for ALL decays. More work is needed to change the decay table
reading code (EvtGenBase/EvtDecayTable) to enable/disable PHOTOS for TAUOLA decays only.
